==> sptk-2.3.28.tbz2: sptk-2.3.28/src/CStringStack.cpp <==
/***************************************************************************
                          SIMPLY POWERFUL TOOLKIT (SPTK)
                          CStringStack.cpp  -  description
                             -------------------
    begin                : Mon Aug 4 2003
    copyright            : (C) 2000-2003 by Alexey S.Parshin
    email                : alexeyp@gmail.com
 ***************************************************************************/

/***************************************************************************
   This library is free software; you can redistribute it and/or modify it 
   under the terms of the GNU Library General Public License as published by
   the Free Software Foundation; either version 2 of the License, or (at 
   your option) any later version.

   This library is distributed in the hope that it will be useful, but 
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Library
   General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; if not, write to the Free Software Foundation, 
   Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.

   Please report all bugs and problems to "alexeyp@gmail.com"
 ***************************************************************************/

#include <sptk/CStringStack.h>
#include <sptk/CException.h>

CString CStringStack::pop() {
   unsigned cnt = count();
   if (cnt) {
      cnt--;
      CString result = operator[](cnt);
      remove(cnt);
      return result;
   }
   throw CException("The stack is empty");
}

CString& CStringStack::top() {
   unsigned cnt = count();
   if (cnt)
      return operator[](cnt-1);
   throw CException("The stack is empty");
}

==> sptk-3.0.6.tbz2: sptk-3.0.6/src/CStringStack.cpp <==
/***************************************************************************
                          SIMPLY POWERFUL TOOLKIT (SPTK)
                          CStringStack.cpp  -  description
                             -------------------
    begin                : Mon Aug 4 2003
    copyright            : (C) 2000-2005 by Alexey S.Parshin
    email                : alexeyp@gmail.com
 ***************************************************************************/

/***************************************************************************
   This library is free software; you can redistribute it and/or modify it 
   under the terms of the GNU Library General Public License as published by
   the Free Software Foundation; either version 2 of the License, or (at 
   your option) any later version.

   This library is distributed in the hope that it will be useful, but 
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Library
   General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; if not, write to the Free Software Foundation, 
   Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.

   Please report all bugs and problems to "alexeyp@gmail.com"
 ***************************************************************************/

#include <sptk/CStringStack.h>
#include <sptk/CException.h>

std::string CStringStack::pop() {
   unsigned cnt = size();
   if (cnt) {
      cnt--;
      std::string result = operator[](cnt);
      remove(cnt);
      return result;
   }
   throw CException("The stack is empty");
}

std::string& CStringStack::top() {
   unsigned cnt = size();
   if (cnt)
      return operator[](cnt-1);
   throw CException("The stack is empty");
}
